@@ -1,5 +1,5 @@
 from collections import defaultdict
-from typing import List, MutableMapping, overload, Literal
+from typing import Literal, MutableMapping, overload
 
 import pywikibot
 
@@ -42,7 +42,7 @@ def merge_reference_groups(
 
 
 class OutputHelper(
-    defaultdict[str, List[ExtraProperty]], MutableMapping[str, List[ExtraProperty]]
+    defaultdict[str, list[ExtraProperty]], MutableMapping[str, list[ExtraProperty]]
 ):
     def __init__(self):
         super().__init__(list)
@@ -50,15 +50,54 @@ class OutputHelper(
     def add_property(self, prop: ExtraProperty):
         self[prop.claim.getID()].append(prop)
 
+
 @overload
-def get_sparql_query(property_val: str, *, multiple_or=True, or_return_value=False, filter_out_unknown_value: bool = True) -> dict[str, str]: ...
+def get_sparql_query(
+    property_val: str,
+    *,
+    multiple_or=True,
+    or_return_value=False,
+    filter_out_unknown_value: bool = True,
+) -> dict[str, set[str]]:
+    ...
+
+
 @overload
-def get_sparql_query(*property_values: str, multiple_or: Literal[True]=True, or_return_value: Literal[False]=False, filter_out_unknown_value: bool = True) -> list[str]: ...
+def get_sparql_query(
+    *property_values: str,
+    multiple_or: Literal[True] = True,
+    or_return_value: Literal[False] = False,
+    filter_out_unknown_value: bool = True,
+) -> set[str]:
+    ...
+
+
 @overload
-def get_sparql_query(*property_values: str, multiple_or: Literal[True]=True, or_return_value: Literal[True]=True, filter_out_unknown_value: bool = True) -> dict[str, dict[str, str]]: ...
+def get_sparql_query(
+    *property_values: str,
+    multiple_or: Literal[True] = True,
+    or_return_value: Literal[True] = True,
+    filter_out_unknown_value: bool = True,
+) -> dict[str, dict[str, set[str]]]:
+    ...
+
+
 @overload
-def get_sparql_query(*property_values: str, multiple_or: Literal[False]=False, or_return_value: bool=True, filter_out_unknown_value: bool = True) -> dict[str, dict[str, str]]: ...
-def get_sparql_query(*property_values: str, multiple_or=True, or_return_value=False, filter_out_unknown_value: bool = True):
+def get_sparql_query(
+    *property_values: str,
+    multiple_or: Literal[False] = False,
+    or_return_value: bool = True,
+    filter_out_unknown_value: bool = True,
+) -> dict[str, dict[str, set[str]]]:
+    ...
+
+
+def get_sparql_query(
+    *property_values: str,
+    multiple_or=True,
+    or_return_value=False,
+    filter_out_unknown_value: bool = True,
+):
     """Get the requests of a SPARQL query.
 
     Args:
@@ -96,17 +135,29 @@ def get_sparql_query(*property_values: str, multiple_or=True, or_return_value=Fa
     r.raise_for_status()
     data = r.json()
     if not or_return_value:
-        return [item["item"]["value"].split("/")[-1] for item in data["results"]["bindings"]]
-    elif len(property_values) == 1:
         return {
-            item["item"]["value"].split("/")[-1]: item[f"prop{property_values[0]}"]["value"]
-            for item in data["results"]["bindings"]
+            item["item"]["value"].split("/")[-1] for item in data["results"]["bindings"]
         }
+    elif len(property_values) == 1:
+        retval = defaultdict(set)
+        for item in data["results"]["bindings"]:
+            if filter_out_unknown_value and ".well-known" in str(item[f"prop{property_values[0]}"][
+                "value"
+            ]):
+                continue
+            retval[item["item"]["value"].split("/")[-1]].add(item[f"prop{property_values[0]}"][
+                "value"
+            ])
+        return dict(retval)
     else:
-        retval = {
-            item["item"]["value"].split("/")[-1]: {
-                prop: (item[f"prop{prop}"]["value"] if f"prop{prop}" in item else None) for prop in property_values
-            }
-            for item in data["results"]["bindings"]
-        }
-        return dict(filter(lambda data: not any(".well-known" in str(val) for val in data[1].values()), retval.items())) if filter_out_unknown_value else retval
\ No newline at end of file
+        retval = defaultdict(lambda: defaultdict(set))
+        for item in data["results"]["bindings"]:
+            for prop in property_values:
+                if filter_out_unknown_value and ".well-known" in str(item[f"prop{prop}"][
+                    "value"
+                ]):
+                    continue
+                retval[item["item"]["value"].split("/")[-1]][prop].add(item[f"prop{prop}"][
+                    "value"
+                ])
+        return dict(retval)
